au_test_harness: switch to the test image

The qemu image is the same as the test image, so we're not producing
it anymore, so switch to the test image directly.

BUG=b:187794257
TEST=CQ passes

Change-Id: I0c2e90efab625d05e2f13f9863898e534722e298
Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/crostestutils/+/2988463
Tested-by: Mike Frysinger <vapier@chromium.org>
Reviewed-by: Jim Pollock <jmpollock@chromium.org>
Reviewed-by: Jaques Clapauch <jaquesc@google.com>
Commit-Queue: Jaques Clapauch <jaquesc@google.com>
Auto-Submit: Mike Frysinger <vapier@chromium.org>
diff --git a/au_test_harness/au_worker.py b/au_test_harness/au_worker.py
index 01b59f6..408f15d 100644
--- a/au_test_harness/au_worker.py
+++ b/au_test_harness/au_worker.py
@@ -110,9 +110,9 @@
 
   def PrepareVMBase(self, image_path, signed_base):
     """Prepares a VM image for worker test."""
     # Tells the VM tests to use the Qemu image as the start point.
     self.vm_image_path = os.path.join(os.path.dirname(image_path),
-                                      'chromiumos_qemu_image.bin')
+                                      'chromiumos_test_image.bin')
     if signed_base:
       self.vm_image_path = self.vm_image_path + '.signed'
@@ -110,9 +110,9 @@
   def PrepareVMBase(self, image_path, signed_base):
     """Prepares a VM image for worker test."""
-    # Tells the VM tests to use the Qemu image as the start point.
+    # Tells the VM tests to use the test Qemu image as the start point.
     self.vm_image_path = os.path.join(os.path.dirname(image_path),